Crate qubit_command

Crate qubit_command 

Qubit Command

Provides command-line process running utilities for Rust.

Author

Haixing Hu

Structs

Command
Structured description of an external command to run.
CommandOutput
Captured output and status information from a finished command.
CommandRunner
Runs external commands and captures their output.

Enums

CommandError
Error returned while spawning, waiting for, or validating a command.
OutputStream
Output stream whose reader failed.

Constants

DEFAULT_COMMAND_TIMEOUT
Default command execution timeout.