pub enum CommandError {
SpawnFailed {
command: String,
source: Error,
},
WaitFailed {
command: String,
source: Error,
},
KillFailed {
command: String,
timeout: Duration,
source: Error,
},
ReadOutputFailed {
command: String,
stream: OutputStream,
source: Error,
},
OpenInputFailed {
command: String,
path: PathBuf,
source: Error,
},
OpenOutputFailed {
command: String,
stream: OutputStream,
path: PathBuf,
source: Error,
},
WriteInputFailed {
command: String,
source: Error,
},
WriteOutputFailed {
command: String,
stream: OutputStream,
path: PathBuf,
source: Error,
},
TimedOut {
command: String,
timeout: Duration,
output: Box<CommandOutput>,
},
UnexpectedExit {
command: String,
exit_code: Option<i32>,
expected: Vec<i32>,
output: Box<CommandOutput>,
},
}Expand description
Variants
SpawnFailed
The process could not be spawned.
Fields
WaitFailed
Waiting for process completion failed.
Fields
KillFailed
The process could not be killed after exceeding the configured timeout.
Fields
ReadOutputFailed
Reading one of the captured output streams failed.
Fields
stream: OutputStreamStream whose reader failed.
OpenInputFailed
Opening a stdin file failed.
Fields
OpenOutputFailed
Opening an output redirection file failed.
Fields
stream: OutputStreamStream whose file could not be opened.
WriteInputFailed
Writing configured stdin bytes failed.
Fields
WriteOutputFailed
Writing captured output to a redirection file failed.
Fields
stream: OutputStreamStream whose redirected writer failed.
TimedOut
The command exceeded the configured timeout and was terminated.
Fields
output: Box<CommandOutput>Captured output available after terminating the child process.
UnexpectedExit
The command completed with an exit code not configured as successful.
Implementations
Sourceimpl CommandError
impl CommandError
Sourcepub const fn output(&self) -> Option<&CommandOutput>
pub const fn output(&self) -> Option<&CommandOutput>
Returns captured command output when this error carries it.
Returns
Some(output) for timeout and unexpected-exit errors, otherwise None.