Structs
- Command
- Structured description of an external command to run.
- Command
Output - Captured output and status information from a finished command.
- Command
Runner - Runs external commands and captures their output.
Enums
- Command
Error - Error returned while spawning, waiting for, or validating a command.
- Output
Stream - Output stream whose reader failed.
Constants
- DEFAULT_
COMMAND_ TIMEOUT - Default command execution timeout.